@@ -1,7 +1,3 @@
-import re
-
-from pathlib import Path
-
 """
 ---------------------------------------
    _____                    _      
@@ -14,10 +10,8 @@ A small library for parsing configuration files.
 Supports secsie and ini formats. Not suitable for writing .ini files, but reads them just fine.
 """
 
-__version__ = 'v2.0.0'
+__version__ = 'v2.0.3'
 __author__ = 'Noah Broyles'
-
-
 __all__ = [
     'InvalidSyntax',
     'parse_config',
@@ -26,21 +20,25 @@ __all__ = [
     'generate_config_file'
 ]
 
+import re
+from pathlib import Path
+
+
 MODES = {
     "secsie": dict(
         SECTION_EX = re.compile(r'\[([a-zA-Z0-9_]+)\]'),
         FLOAT_EX = re.compile(r'^([-]?\d+[\.]\d*)$'),
-        FALSE_EX = re.compile(r'(false|no)', re.IGNORECASE),
-        NULL_EX = re.compile(r'null', re.IGNORECASE),
-        TRUE_EX = re.compile(r'(true|yes)', re.IGNORECASE),
+        FALSE_EX = re.compile(r'^(false|no)$', re.IGNORECASE),
+        NULL_EX = re.compile(r'^null$', re.IGNORECASE),
+        TRUE_EX = re.compile(r'^(true|yes)$', re.IGNORECASE),
         INT_EX = re.compile(r'^[-]?\d+$')
     ),
     "ini": dict(
         SECTION_EX = re.compile(r'\[([a-zA-Z0-9 _-]+)\]'),
         FLOAT_EX = re.compile(r'^([-]?\d+[\.]\d*)$'),
-        FALSE_EX = re.compile(r'(false|no)', re.IGNORECASE),
-        NULL_EX = re.compile(r'null', re.IGNORECASE),
-        TRUE_EX = re.compile(r'(true|yes)', re.IGNORECASE),
+        FALSE_EX = re.compile(r'^(false|no)$', re.IGNORECASE),
+        NULL_EX = re.compile(r'^null$', re.IGNORECASE),
+        TRUE_EX = re.compile(r'^(true|yes)$', re.IGNORECASE),
         INT_EX = re.compile(r'^[-]?\d+$')
     )
 }
